reconstruct_fw_path

Function reconstruct_fw_path 

pub fn reconstruct_fw_path(
    next: &[Vec<Option<NodeId>>],
    start: NodeId,
    end: NodeId,
) -> Option<Vec<NodeId>>
Reconstructs a shortest path using the next table from floyd_warshall_with_paths.

Returns None if no path exists from start to end.